Converting skins to views:
==========================

Discussions

- [?] talkback_tree.pt (macros)
- [?] setup_talkback_tree.py

[x] IDiscussionResponse @@view:
-------------------------------
- [x] discussionitem_view.py -> discussion.View
- [x] aboveInThread.py -> discussion.View.aboveInThread
- [x] discussionitem_view_template.pt -> discussion.pt

[ ] IDiscussionResponse @@edit:
-------------------------------
- [ ] discussion_reply_form.py
- [ ] validateHTML.py
- [ ] discussion_reply.py
- [ ] discussion_reply_template.pt

[ ] IDiscussionResponse @@delete:
---------------------------------
- [x] discitem_delete.py
